@@ -4,9 +4,10 @@ import json
 
 from abc import ABCMeta, abstractmethod
 from collections import defaultdict
-from tqdm import trange
+from tqdm.auto import tqdm
 from .preprocessing import create_scaler, Scaler
-from .augmentation import create_augmentation, AugmentationPipeline
+from .augmentation import create_augmentation, AugmentationPipeline, DrQPipeline
+from .augmentation import DrQPipeline
 from .dataset import TransitionMiniBatch
 from .logger import D3RLPyLogger
 from .metrics.scorer import NEGATED_SCORER
@@ -14,7 +15,9 @@ from .context import disable_parallel
 from .gpu import Device
 from .optimizers import OptimizerFactory
 from .encoders import EncoderFactory, create_encoder_factory
+from .q_functions import QFunctionFactory, create_q_func_factory
 from .argument_utils import check_scaler
+from .online.utility import get_action_size_from_env
 
 
 class ImplBase(metaclass=ABCMeta):
@@ -31,12 +34,7 @@ def _serialize_params(params):
     for key, value in params.items():
         if isinstance(value, Device):
             params[key] = value.get_id()
-        elif isinstance(value, Scaler):
-            params['scaler'] = {
-                'type': value.get_type(),
-                'params': value.get_params()
-            }
-        elif isinstance(value, EncoderFactory):
+        elif isinstance(value, (Scaler, EncoderFactory, QFunctionFactory)):
             params[key] = {
                 'type': value.get_type(),
                 'params': value.get_params()
@@ -46,9 +44,12 @@ def _serialize_params(params):
         elif isinstance(value, AugmentationPipeline):
             aug_types = value.get_augmentation_types()
             aug_params = value.get_augmentation_params()
-            params[key] = []
+            params[key] = {'params': value.get_params(), 'augmentations': []}
             for aug_type, aug_param in zip(aug_types, aug_params):
-                params[value].append({'type': aug_type, 'params': aug_param})
+                params[key]['augmentations'].append({
+                    'type': aug_type,
+                    'params': aug_param
+                })
     return params
 
 
@@ -61,17 +62,20 @@ def _deseriealize_params(params):
             params[key] = scaler
         elif key == 'augmentation' and params['augmentation']:
             augmentations = []
-            for param in params[key]:
+            for param in params[key]['augmentations']:
                 aug_type = param['type']
                 aug_params = param['params']
                 augmentation = create_augmentation(aug_type, **aug_params)
                 augmentations.append(augmentation)
-            params[key] = AugmentationPipeline(augmentations)
+            params[key] = DrQPipeline(augmentations, **params[key]['params'])
         elif 'optim_factory' in key:
             params[key] = OptimizerFactory(**value)
         elif 'encoder_factory' in key:
             params[key] = create_encoder_factory(value['type'],
                                                  **value['params'])
+        elif key == 'q_func_factory':
+            params[key] = create_q_func_factory(value['type'],
+                                                **value['params'])
     return params
 
 
@@ -92,9 +96,11 @@ class LearnableBase:
         active_logger_ (d3rlpy.logger.D3RLPyLogger): active logger during fit method.
 
     """
-    def __init__(self, batch_size, n_frames, scaler):
+    def __init__(self, batch_size, n_frames, n_steps, gamma, scaler):
         self.batch_size = batch_size
         self.n_frames = n_frames
+        self.n_steps = n_steps
+        self.gamma = gamma
         self.scaler = check_scaler(scaler)
 
         self.impl = None
@@ -255,7 +261,8 @@ class LearnableBase:
             tensorboard=True,
             eval_episodes=None,
             save_interval=1,
-            scorers=None):
+            scorers=None,
+            shuffle=True):
         """ Trains with the given dataset.
 
         .. code-block:: python
@@ -282,6 +289,7 @@ class LearnableBase:
             save_interval (int): interval to save parameters.
             scorers (list(callable)):
                 list of scorer functions used with `eval_episodes`.
+            shuffle (bool): flag to shuffle transitions on each epoch.
 
         """
 
@@ -294,15 +302,12 @@ class LearnableBase:
             self.scaler.fit(episodes)
 
         # instantiate implementation
-        observation_shape = tuple(transitions[0].get_observation_shape())
-        # frame stacking for image observation
-        if len(observation_shape) == 3:
-            n_channels = observation_shape[0]
-            image_size = observation_shape[1:]
-            observation_shape = (self.n_frames * n_channels, *image_size)
-        action_size = transitions[0].get_action_size()
         if self.impl is None:
-            self.create_impl(observation_shape, action_size)
+            action_size = transitions[0].get_action_size()
+            observation_shape = tuple(transitions[0].get_observation_shape())
+            self.create_impl(
+                self._process_observation_shape(observation_shape),
+                action_size)
 
         # setup logger
         logger = self._prepare_logger(save_metrics, experiment_name,
@@ -333,29 +338,54 @@ class LearnableBase:
             if new_transitions:
                 transitions = env_transitions + new_transitions
 
-            indices = np.random.permutation(np.arange(len(transitions)))
+            # shuffle data
+            if shuffle:
+                indices = np.random.permutation(np.arange(len(transitions)))
+            else:
+                indices = np.arange(len(transitions))
+
+            # dict to add incremental mean losses to epoch
+            epoch_loss = defaultdict(list)
+
             n_iters = len(transitions) // self.batch_size
-            range_gen = trange(n_iters) if show_progress else range(n_iters)
+            range_gen = tqdm(range(n_iters),
+                             disable=not show_progress,
+                             desc='Epoch %d' % int(epoch))
+
             for itr in range_gen:
                 # pick transitions
-                batch = []
+                sampled_transitions = []
                 head_index = itr * self.batch_size
                 for index in indices[head_index:head_index + self.batch_size]:
-                    batch.append(transitions[index])
+                    sampled_transitions.append(transitions[index])
 
-                loss = self.update(epoch, total_step,
-                                   TransitionMiniBatch(batch, self.n_frames))
+                batch = TransitionMiniBatch(transitions=sampled_transitions,
+                                            n_frames=self.n_frames,
+                                            n_steps=self.n_steps,
+                                            gamma=self.gamma)
+
+                loss = self.update(epoch, total_step, batch)
 
                 # record metrics
                 for name, val in zip(self._get_loss_labels(), loss):
                     if val is not None:
                         logger.add_metric(name, val)
+                        epoch_loss[name].append(val)
 
-                        # save loss to loss history dict
-                        self.loss_history_[name].append(val)
+                # update progress postfix with losses
+                if itr % 10 == 0:
+                    mean_loss = {k: np.mean(v) for k, v in epoch_loss.items()}
+                    range_gen.set_postfix(mean_loss)
 
                 total_step += 1
 
+            # save loss to loss history dict
+            self.loss_history_['epoch'].append(epoch)
+            self.loss_history_['step'].append(total_step)
+            for name in self._get_loss_labels():
+                if name in epoch_loss:
+                    self.loss_history_[name].append(np.mean(epoch_loss[name]))
+
             if scorers and eval_episodes:
                 self._evaluate(eval_episodes, scorers, logger)
 
@@ -382,6 +412,36 @@ class LearnableBase:
         """
         raise NotImplementedError
 
+    def build_with_dataset(self, dataset):
+        """ Instantiate implementation object with MDPDataset object.
+
+        Args:
+            dataset (d3rlpy.dataset.MDPDataset): dataset.
+
+        """
+        observation_shape = dataset.get_observation_shape()
+        self.create_impl(self._process_observation_shape(observation_shape),
+                         dataset.get_action_size())
+
+    def build_with_env(self, env):
+        """ Instantiate implementation object with OpenAI Gym object.
+
+        Args:
+            env (gym.Env): gym-like environment.
+
+        """
+        observation_shape = env.observation_space.shape
+        self.create_impl(self._process_observation_shape(observation_shape),
+                         get_action_size_from_env(env))
+
+    def _process_observation_shape(self, observation_shape):
+        if len(observation_shape) == 3:
+            n_channels = observation_shape[0]
+            image_size = observation_shape[1:]
+            # frame stacking for image observation
+            observation_shape = (self.n_frames * n_channels, *image_size)
+        return observation_shape
+
     def update(self, epoch, total_step, batch):
         """ Update parameters with mini-batch of data.
 
